/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package constant

// transfer
const (
	// TRIPLE is triple protocol name
	TRIPLE = "tri"

	// DefaultHttp2ControllerReadBufferSize is default read buffer size of triple client/server
	DefaultHttp2ControllerReadBufferSize = 1000000

	// DefaultTimeout is default timeout seconds of triple client
	DefaultTimeout = 15

	// DefaultListeningAddress is default listening address
	DefaultListeningAddress = "127.0.0.1:20001"
)

// serializer
// CodecType is the type of triple serializer
type CodecType string

const (
	// PBCodecName is the default serializer name, triple use pb as serializer.
	PBCodecName = CodecType("protobuf")

	// HessianCodecName is the serializer with pb wrapped with hessian2
	HessianCodecName = CodecType("hessian2")

	// MsgPackCodecName is the serializer with pb wrapped with msgpack
	MsgPackCodecName = CodecType("msgpack")
)

// context key
type TripleCtxKey string

const (
	InterfaceKey = TripleCtxKey("interface")
)

// triple Header

// TrailerKeys are to make triple compatible with grpc
// After server returning the rsp header and body, it returns Trailer header in the end, to send grpc status of this invocation.
const (
	// TrailerKeyGrpcStatus is a trailer header field to response grpc code (int).
	TrailerKeyGrpcStatus = "grpc-status"

	// TrailerKeyGrpcMessage is a trailer header field to response grpc error message.
	TrailerKeyGrpcMessage = "grpc-message"

	// TrailerKeyTraceProtoBin is triple trailer header
	TrailerKeyTraceProtoBin = "trace-proto-bin"
)

const (
	TripleUserAgent      = "grpc-go/1.35.0-dev"
	TripleServiceVersion = "tri-service-version"
	TripleServiceGroup   = "tri-service-group"
	TripleRequestID      = "tri-req-id"
	TripleTraceID        = "tri-trace-traceid"
	TripleTraceRPCID     = "tri-trace-rpcid"
	TripleTraceProtoBin  = "tri-trace-proto-bin"
	TripleUnitInfo       = "tri-unit-info"
)
